import { Emitter } from 'mitt';
import { Handler } from 'mitt';

export declare type AvailableLanguages = 'en' | 'pt' | 'de' | 'es' | 'fr' | 'it' | 'nl' | 'sv';

export declare type AvailableThemes = 'dark' | 'red' | 'pink' | 'purple' | 'deep-purple' | 'indigo' | 'blue' | 'light-blue' | 'cyan' | 'teal' | 'green' | 'light-green' | 'lime' | 'yellow' | 'amber' | 'orange' | 'deep-orange' | 'brown' | 'blue-grey';

export declare type EmitterClientEvents = {
    [Events.OPEN]: {
        element: Picker['target']['element'];
    };
    [Events.CLOSE]: {
        element: Picker['target']['element'];
    };
    [Events.CHANGE]: {
        hour: Picker['hour'];
        minute: Picker['minute'];
        element: Picker['target']['element'];
    };
};

export declare type EmitterEvents = {
    [InternalEvents.START_FADE_IN]: Picker['target']['element'];
    [InternalEvents.START_FADE_OUT]: Picker['target']['element'];
    [InternalEvents.END_FADE_IN]: Picker['target']['element'];
    [InternalEvents.END_FADE_OUT]: Picker['target']['element'];
};

export declare const Events: {
    readonly OPEN: "open";
    readonly CLOSE: "close";
    readonly CHANGE: "change";
};

export declare const InternalEvents: {
    readonly START_FADE_IN: "start-fade-in";
    readonly END_FADE_IN: "end-fade-in";
    readonly START_FADE_OUT: "start-fade-out";
    readonly END_FADE_OUT: "end-fade-out";
};

export declare type Language = Record<AvailableLanguages, {
    hour: string;
    minute: string;
}>;

export declare type Options = {
    lang: AvailableLanguages;
    theme: AvailableThemes;
};

export declare type Picker = {
    options: Options;
    target: {
        element: HTMLElement;
        offset: {
            width: number;
            height: number;
            top: number;
            bottom: number;
            right: number;
            left: number;
        };
    };
    hour: string;
    minute: string;
    opened: boolean;
    requestAnimationId: number;
    closeWhen: {
        hour: boolean;
        minute: boolean;
    };
    collection: {
        hours: NodeListOf<HTMLAnchorElement>;
        minutes: NodeListOf<HTMLAnchorElement>;
    };
    container: {
        element: HTMLDivElement;
        dragElement: HTMLElement;
        lastX: number;
        lastY: number;
        currentX: number;
        currentY: number;
        x: number;
        y: number;
        size: {
            width: number;
            height: number;
        };
    };
};

export declare type PickerDragHandler = {
    start: () => void;
    move: ({ x, y }: {
        x: number;
        y: number;
    }) => void;
    end: ({ x, y }: {
        x: number;
        y: number;
    }) => void;
};

declare class TimePicker {
    container: Picker['container']['element'];
    protected emitter: Emitter<EmitterEvents & EmitterClientEvents>;
    protected picker: Picker;
    constructor(target: string | Picker['target']['element'], opts?: Partial<Options>);
    private setDomListeners;
    private handleClickOutside;
    private triggerShow;
    private handleAnchorClick;
    show(): void;
    hide(): void;
    on<Key extends keyof EmitterClientEvents>(type: Key, handler: Handler<EmitterClientEvents[Key]>): void;
    private getHour;
    private getMinute;
}
export default TimePicker;

export { }
